==> svn-workbench_1.6.8.orig.tar.gz: WorkBench-1.6.8/Source/wb_diff_main.py <==
'''
 ====================================================================
 Copyright (c) 2003-2010 Barry A Scott.  All rights reserved.

 This software is licensed as described in the file LICENSE.txt,
 which you should have received as part of this distribution.

 ====================================================================


    wb_diff_main.py

'''

VERSION_STRING = "Uncontrolled"

import sys

# make sure that we get 2.6 and not an earlier version
# 2.8 is reported to work as well
if not hasattr(sys, 'frozen'):
    import wxversion
    wxversion.select( ['2.8', '2.9'] )

def noTranslate(msg):
    return msg

import __builtin__
__builtin__.__dict__['T_'] = noTranslate
__builtin__.__dict__['U_'] = noTranslate

import wx
import wb_diff_frame
import wb_preferences
import wb_platform_specific



class WbDiffApp:
    def __init__( self ):
        self.log = self
        self.prefs = wb_preferences.Preferences(
                self,
                wb_platform_specific.getPreferencesFilename(),
                wb_platform_specific.getOldPreferencesFilename() )

    def info( self, *arg ):
        pass

        
def main():
    if len(sys.argv) < 3:
        print 'Usages: wb_diff file1 file2'
        return 1

    file1 = sys.argv[1]
    file2 = sys.argv[2]

    diff_app = WbDiffApp()
    app = wx.PySimpleApp()
    frame = wb_diff_frame.DiffFrame( diff_app, None, file1, file1, file2, file2 )

    frame.Show( True )
    app.MainLoop()
    return 0

if __name__ == '__main__':
    main()

==> svn-workbench_1.8.2.orig.tar.gz: WorkBench-1.8.2/Source/wb_diff_main.py <==
'''
 ====================================================================
 Copyright (c) 2003-2010 Barry A Scott.  All rights reserved.

 This software is licensed as described in the file LICENSE.txt,
 which you should have received as part of this distribution.

 ====================================================================


    wb_diff_main.py

'''

VERSION_STRING = "Uncontrolled"

import sys

# make sure that we get 2.8 or 3.0 and not an earlier version
if not hasattr(sys, 'frozen'):
    import wxversion
    wxversion.select( ['3.0', '2.8'] )

def noTranslate(msg):
    return msg

import __builtin__
__builtin__.__dict__['T_'] = noTranslate
__builtin__.__dict__['U_'] = noTranslate

import wx
import wb_diff_frame
import wb_preferences
import wb_platform_specific



class WbDiffApp(wx.App):
    def __init__( self, file1, file2 ):
        self.file1 = file1
        self.file2 = file2
        self.log = self
        self.prefs = wb_preferences.Preferences(
                self,
                wb_platform_specific.getPreferencesFilename(),
                wb_platform_specific.getOldPreferencesFilename() )

        wx.App.__init__( self, 0 )

    def OnInit( self ):
        self.frame = wb_diff_frame.DiffFrame( self, None, self.file1, self.file1, self.file2, self.file2 )
        self.frame.Show( True )
        self.SetTopWindow( self.frame )

        return True

    def info( self, *arg ):
        pass

        
def main():
    if len(sys.argv) < 3:
        print 'Usages: wb_diff file1 file2'
        return 1

    file1 = sys.argv[1]
    file2 = sys.argv[2]

    diff_app = WbDiffApp( file1, file2 )
    diff_app.MainLoop()
    return 0

if __name__ == '__main__':
    main()
